package com.biganto.visual.roompark.presentation.screen.feeds.utils

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.domain.model.ArticlePreviewModel
import com.squareup.picasso.Picasso
import java.text.SimpleDateFormat
import java.util.*


/**
 * Created by Vladislav Bogdashkin on 15.10.2019.
 */
class ArticlesPreviewAdapter : RecyclerView.Adapter<ArticlePreviewViewHolder>() {

    private var list: MutableList<ArticlePreviewModel> = mutableListOf()


    fun addItems(list:List<ArticlePreviewModel>){
        this.list.clear()
        this.list.addAll(list)
        notifyDataSetChanged()
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ArticlePreviewViewHolder =
        ArticlePreviewViewHolder(
            LayoutInflater.from(parent.context)
                .inflate(R.layout.feed_viewholder, parent, false)
        )

    override fun getItemCount(): Int = list.size

    override fun onBindViewHolder(holder: ArticlePreviewViewHolder, position: Int) {
        holder.bindModel(list[position])
    }
}




class ArticlePreviewViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

    private val dateFormatter = SimpleDateFormat("dd / MM / yyyy", Locale.getDefault())

    @BindView(R.id.imageHolder) lateinit var preview:ImageView
    @BindView(R.id.feed_date_text_view) lateinit var articleDate:TextView
    @BindView(R.id.feed_title_info_text_view) lateinit var articleTitle:TextView
    @BindView(R.id.feed_read) lateinit var articleIsRead:View


    init {
        ButterKnife.bind(this, itemView)
    }

    fun bindModel(model: ArticlePreviewModel){
        articleDate.text = dateFormatter.format(model.published)
        articleTitle.text = model.title
        articleIsRead.setGone(model.isRead)

        Picasso.get()
            .load(model.previewUrl)
            .into(preview)
    }

}

fun View.setGone(isGone:Boolean){
    this.visibility = if (isGone) View.GONE else View.VISIBLE
}